==> molview_messages-0.2.3.tar.gz: lib/src/standards/values.dart <==
// Copyright (c) 2016, Herman Bergwerf. All rights reserved.
// Use of this source code is governed by an AGPL-3.0-style license
// that can be found in the LICENSE file.

part of molview_messages.standards;

/// Some common molecular properties. This list is based on the properties
/// provided by PubChem, see:
/// https://pubchem.ncbi.nlm.nih.gov/pug_rest/PUG_REST.html

/// Molecular formula
class MolecularFormula extends TableValue {
  static const String id = '${entityMolecule}_MolecularFormula';
  const MolecularFormula(
      [bool array = false, Map<String, dynamic> properties = const {}])
      : super(DataType.text, id, array, properties);
}

/// Molecular weight
class MolecularWeight extends TableValue {
  static const String id = '${entityMolecule}_MolecularWeight';
  const MolecularWeight(
      [bool array = false, Map<String, dynamic> properties = const {}])
      : super(DataType.real, id, array, properties);
}

/// XLogP
class XLopP extends TableValue {
  static const String id = '${entityMolecule}_XLopP';
  const XLopP([bool array = false, Map<String, dynamic> properties = const {}])
      : super(DataType.real, id, array, properties);
}

/// Exact mass
class ExactMass extends TableValue {
  static const String id = '${entityMolecule}_ExactMass';
  const ExactMass(
      [bool array = false, Map<String, dynamic> properties = const {}])
      : super(DataType.real, id, array, properties);
}

/// Monoisotopic mass
class MonoisotopicMass extends TableValue {
  static const String id = '${entityMolecule}_MonoisotopicMass';
  const MonoisotopicMass(
      [bool array = false, Map<String, dynamic> properties = const {}])
      : super(DataType.real, id, array, properties);
}

/// Topological Polar Surface Area
class TPSA extends TableValue {
  static const String id = '${entityMolecule}_TPSA';
  const TPSA([bool array = false, Map<String, dynamic> properties = const {}])
      : super(DataType.real, id, array, properties);
}

/// Complexity using the Bertz/Hendrickson/Ihlenfeldt formula
class Complexity extends TableValue {
  static const String id = '${entityMolecule}_Complexity';
  const Complexity(
      [bool array = false, Map<String, dynamic> properties = const {}])
      : super(DataType.integer, id, array, properties);
}

/// Electrical charge
class ElecticalCharge extends TableValue {
  static const String id = '${entityMolecule}_ElecticalCharge';
  const ElecticalCharge(
      [bool array = false, Map<String, dynamic> properties = const {}])
      : super(DataType.real, id, array, properties);
}

/// Number of hydrogen bond donors
class HBondDonorCount extends TableValue {
  static const String id = '${entityMolecule}_HBondDonorCount';
  const HBondDonorCount(
      [bool array = false, Map<String, dynamic> properties = const {}])
      : super(DataType.integer, id, array, properties);
}

/// Number of hydrogen bond acceptors
class HBondAcceptorCount extends TableValue {
  static const String id = '${entityMolecule}_HBondAcceptorCount';
  const HBondAcceptorCount(
      [bool array = false, Map<String, dynamic> properties = const {}])
      : super(DataType.integer, id, array, properties);
}

/// Number of rotatable bonds
class RotatableBondCount extends TableValue {
  static const String id = '${entityMolecule}_RotatableBondCount';
  const RotatableBondCount(
      [bool array = false, Map<String, dynamic> properties = const {}])
      : super(DataType.integer, id, array, properties);
}

==> molview_messages-0.3.0.tar.gz: lib/src/standards/values.dart <==
// Copyright (c) 2016, Herman Bergwerf. All rights reserved.
// Use of this source code is governed by an AGPL-3.0-style license
// that can be found in the LICENSE file.

part of molview_messages.standards;

/// Some common molecular properties. This list is based on the properties
/// provided by PubChem, see:
/// https://pubchem.ncbi.nlm.nih.gov/pug_rest/PUG_REST.html

/// Molecular formula
class MolecularFormula extends TableValue {
  static const String id = '${entityMolecule}_MolecularFormula';
  const MolecularFormula(
      [bool array = false, Map<String, String> properties = const {}])
      : super(DataType.text, id, array, properties);
}

/// Molecular weight
class MolecularWeight extends TableValue {
  static const String id = '${entityMolecule}_MolecularWeight';
  const MolecularWeight(
      [bool array = false, Map<String, String> properties = const {}])
      : super(DataType.real, id, array, properties);
}

/// XLogP
class XLopP extends TableValue {
  static const String id = '${entityMolecule}_XLopP';
  const XLopP([bool array = false, Map<String, String> properties = const {}])
      : super(DataType.real, id, array, properties);
}

/// Exact mass
class ExactMass extends TableValue {
  static const String id = '${entityMolecule}_ExactMass';
  const ExactMass(
      [bool array = false, Map<String, String> properties = const {}])
      : super(DataType.real, id, array, properties);
}

/// Monoisotopic mass
class MonoisotopicMass extends TableValue {
  static const String id = '${entityMolecule}_MonoisotopicMass';
  const MonoisotopicMass(
      [bool array = false, Map<String, String> properties = const {}])
      : super(DataType.real, id, array, properties);
}

/// Topological Polar Surface Area
class TPSA extends TableValue {
  static const String id = '${entityMolecule}_TPSA';
  const TPSA([bool array = false, Map<String, String> properties = const {}])
      : super(DataType.real, id, array, properties);
}

/// Complexity using the Bertz/Hendrickson/Ihlenfeldt formula
class Complexity extends TableValue {
  static const String id = '${entityMolecule}_Complexity';
  const Complexity(
      [bool array = false, Map<String, String> properties = const {}])
      : super(DataType.integer, id, array, properties);
}

/// Electrical charge
class ElecticalCharge extends TableValue {
  static const String id = '${entityMolecule}_ElecticalCharge';
  const ElecticalCharge(
      [bool array = false, Map<String, String> properties = const {}])
      : super(DataType.real, id, array, properties);
}

/// Number of hydrogen bond donors
class HBondDonorCount extends TableValue {
  static const String id = '${entityMolecule}_HBondDonorCount';
  const HBondDonorCount(
      [bool array = false, Map<String, String> properties = const {}])
      : super(DataType.integer, id, array, properties);
}

/// Number of hydrogen bond acceptors
class HBondAcceptorCount extends TableValue {
  static const String id = '${entityMolecule}_HBondAcceptorCount';
  const HBondAcceptorCount(
      [bool array = false, Map<String, String> properties = const {}])
      : super(DataType.integer, id, array, properties);
}

/// Number of rotatable bonds
class RotatableBondCount extends TableValue {
  static const String id = '${entityMolecule}_RotatableBondCount';
  const RotatableBondCount(
      [bool array = false, Map<String, String> properties = const {}])
      : super(DataType.integer, id, array, properties);
}
